==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsLimitsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageRegistryConfigRequestsLimitsFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluent<A>{
  public ImageRegistryConfigRequestsLimitsFluentImpl() {
  }
  public ImageRegistryConfigRequestsLimitsFluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits instance) {
    this.withMaxInQueue(instance.getMaxInQueue()); 
    this.withMaxRunning(instance.getMaxRunning()); 
    this.withMaxWaitInQueue(instance.getMaxWaitInQueue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer maxInQueue;
  private java.lang.Integer maxRunning;
  private io.fabric8.kubernetes.api.model.Duration maxWaitInQueue;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getMaxInQueue() {
    return this.maxInQueue;
  }
  public A withMaxInQueue(java.lang.Integer maxInQueue) {
    this.maxInQueue=maxInQueue; return (A) this;
  }
  public java.lang.Boolean hasMaxInQueue() {
    return this.maxInQueue != null;
  }
  public java.lang.Integer getMaxRunning() {
    return this.maxRunning;
  }
  public A withMaxRunning(java.lang.Integer maxRunning) {
    this.maxRunning=maxRunning; return (A) this;
  }
  public java.lang.Boolean hasMaxRunning() {
    return this.maxRunning != null;
  }
  public io.fabric8.kubernetes.api.model.Duration getMaxWaitInQueue() {
    return this.maxWaitInQueue;
  }
  public A withMaxWaitInQueue(io.fabric8.kubernetes.api.model.Duration maxWaitInQueue) {
    this.maxWaitInQueue=maxWaitInQueue; return (A) this;
  }
  public java.lang.Boolean hasMaxWaitInQueue() {
    return this.maxWaitInQueue != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigRequestsLimitsFluentImpl that = (ImageRegistryConfigRequestsLimitsFluentImpl) o;
    if (maxInQueue != null ? !maxInQueue.equals(that.maxInQueue) :that.maxInQueue != null) return false;
    if (maxRunning != null ? !maxRunning.equals(that.maxRunning) :that.maxRunning != null) return false;
    if (maxWaitInQueue != null ? !maxWaitInQueue.equals(that.maxWaitInQueue) :that.maxWaitInQueue != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxInQueue,  maxRunning,  maxWaitInQueue,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsLimitsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageRegistryConfigRequestsLimitsFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluent<A>{
  public ImageRegistryConfigRequestsLimitsFluentImpl() {
  }
  public ImageRegistryConfigRequestsLimitsFluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits instance) {
    this.withMaxInQueue(instance.getMaxInQueue()); 
    this.withMaxRunning(instance.getMaxRunning()); 
    this.withMaxWaitInQueue(instance.getMaxWaitInQueue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer maxInQueue;
  private java.lang.Integer maxRunning;
  private io.fabric8.kubernetes.api.model.Duration maxWaitInQueue;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getMaxInQueue() {
    return this.maxInQueue;
  }
  public A withMaxInQueue(java.lang.Integer maxInQueue) {
    this.maxInQueue=maxInQueue; return (A) this;
  }
  public java.lang.Boolean hasMaxInQueue() {
    return this.maxInQueue != null;
  }
  public java.lang.Integer getMaxRunning() {
    return this.maxRunning;
  }
  public A withMaxRunning(java.lang.Integer maxRunning) {
    this.maxRunning=maxRunning; return (A) this;
  }
  public java.lang.Boolean hasMaxRunning() {
    return this.maxRunning != null;
  }
  public io.fabric8.kubernetes.api.model.Duration getMaxWaitInQueue() {
    return this.maxWaitInQueue;
  }
  public A withMaxWaitInQueue(io.fabric8.kubernetes.api.model.Duration maxWaitInQueue) {
    this.maxWaitInQueue=maxWaitInQueue; return (A) this;
  }
  public java.lang.Boolean hasMaxWaitInQueue() {
    return this.maxWaitInQueue != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigRequestsLimitsFluentImpl that = (ImageRegistryConfigRequestsLimitsFluentImpl) o;
    if (maxInQueue != null ? !maxInQueue.equals(that.maxInQueue) :that.maxInQueue != null) return false;
    if (maxRunning != null ? !maxRunning.equals(that.maxRunning) :that.maxRunning != null) return false;
    if (maxWaitInQueue != null ? !maxWaitInQueue.equals(that.maxWaitInQueue) :that.maxWaitInQueue != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxInQueue,  maxRunning,  maxWaitInQueue,  additionalProperties,  super.hashCode());
  }
  
}
